@@ -11,6 +11,11 @@ class Status(Enum):
     EXECUTED = 'executed'
     ERROR = 'error'
 
+    @staticmethod
+    def parse(value):
+        result = [member for name, member in Status.__members__.items() if member.value.lower() == value.lower()]
+        return result[0]
+
 
 @dataclass
 class InstrumentTrade:
@@ -18,6 +23,7 @@ class InstrumentTrade:
     instrument_to: str
     quantity: BigFloat
     price: BigFloat = field(default=None)
+    value: BigFloat = field(default=None)
     status: Status = field(default=Status.NEW)
     description: str = field(default=None)
     order_id: str = field(default=None)
